from django import forms
from django.contrib.postgres.fields import ArrayField
from django.db import models

from jnt_django_toolbox.models.fields.widgets import FlagsArrayWidget


class FlagsArrayField(ArrayField):
    def __init__(self, choices, **kwargs):
        if "default" not in kwargs:
            kwargs["default"] = list

        super().__init__(models.TextField(choices=choices), **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            "form_class": forms.MultipleChoiceField,
            "choices": self.base_field.choices,
            "widget": FlagsArrayWidget,
        }
        defaults.update(kwargs)
        # Skip our parent's formfield implementation completely as we don't
        # care for it.
        return super(ArrayField, self).formfield(**defaults)  # noqa:WPS608

    def deconstruct(self):
        name, path, args, kwargs = super().deconstruct()
        kwargs.update(
            {
                "choices": self.base_field.choices,
            },
        )
        kwargs.pop("base_field")
        return name, path, args, kwargs



from django import template
from django.db import models

register = template.Library()


@register.filter_function
def order_by(queryset: models.QuerySet, args):
    """Ordering queryset."""
    return queryset.order_by(
        *[order_field.strip() for order_field in args.split(",")],
    )



import typing as ty

from django.conf import settings


def js_jquery() -> ty.Iterable[str]:
    extra = "" if settings.DEBUG else ".min"

    return [
        "admin/js/{0}".format(path)
        for path in (
            "vendor/jquery/jquery{0}.js".format(extra),
            "jquery.init.js",
        )
    ]
